<?php

namespace App\Http\Livewire;

use App\Models\Animation;
use Carbon\Carbon;
use Livewire\Component;
use Livewire\WithFileUploads;

class AnimationEdit extends Component
{
    use WithFileUploads;

    public $animationId = null;
    public Animation $animation;
    public $photo;
    public $saveMethod = 'store';

    protected $rules = [
        'animation.name' => 'required|string',
        'animation.showman' => 'required|string',
        'animation.date' => 'required|date',
        'animation.showman_link' => 'required|string',
        'animation.entrant_link' => 'required|string',
        'animation.entrant_link_updated' => 'required|string',
        'animation.type' => 'required|string|in:quizz,culture,news',
        'photo' => 'nullable|image|max:8192',
    ];

    public function mount() {
        if($this->animationId) {
            $animation = Animation::where('id', $this->animationId)->firstOrFail();
            $this->animation = $animation;
            $this->saveMethod = 'update';
        } else {
            $this->animation = new Animation();
        }
    }

    public function render()
    {
        return view('livewire.animation-form');
    }

    public function updated($propertyName)
    {
        $this->validateOnly($propertyName);
    }

    public function store()
    {
        $this->validate();
        $this->validate(['photo' => 'required']);

        if($this->photo) {
            try {
                $this->animation->image_url = $this->photo->store('images', 'public');
            } catch (\Exception $e) {
                $this->animation->image_url = 'images/senioranim.png';
                session()->flash('error-message', "Error while uploading image. Setting default. {$e->getMessage()}");
            }
        }

        if($this->animation->save()) {
            $this->password = "";
            session()->flash('message', 'Animation Created Successfully.');
            return redirect()->route('animations.edit', [$this->animation->id]);
        } else {
            session()->flash('error-message', 'An unknown error occured.');
        }
    }

    public function update()
    {
        $this->validate();

        if($this->photo) {
            try {
                $this->animation->image_url = $this->photo->store('images', 'public');
            } catch (\Exception $e) {
                session()->flash('error-message', "Error while uploading image. {$e->getMessage()}");
            }
        }

        if($this->animation->save()) {
            $this->password = "";
            session()->flash('message', 'Animation Updated Successfully.');
        } else {
            session()->flash('error-message', 'An unknown error occured.');
        }
    }
}
