<?php

namespace App\Http\Livewire;

use App\Models\Resident;
use Carbon\Carbon;
use Illuminate\Support\Facades\Hash;
use Livewire\Component;

class ResidentEdit extends Component
{
    public $residentId = null;
    public Resident $resident;
    public $saveMethod = 'store';

    protected $rules = [
        'resident.id_residence' => 'nullable|integer',
        'resident.nom' => 'required|string',
        'resident.prenom' => 'required|string',
    ];

    public function mount() {

        if($this->residentId) {
            $resident = resident::where('id', $this->residentId)->firstOrFail();
            $this->resident = $resident;
            $this->saveMethod = 'update';
        } else {
            $this->resident = new resident();
        }
    }

    public function render()
    {
        return view('livewire.resident-form');
    }

    public function updated($propertyName)
    {
        $this->validateOnly($propertyName);
    }

    public function store()
    {
        $this->validate();
        if($this->resident->save()) {
            session()->flash('message', 'residence Created Successfully.');
            return redirect()->route('resident.edit', [$this->resident->id]);
        } else {
            session()->flash('error-message', 'An unknown error occured.');
        }

    }

    public function update()
    {
        $this->validate();
        if($this->resident->save()) {
            session()->flash('message', 'residence Updated Successfully.');
        } else {
            session()->flash('error-message', 'An unknown error occured.');
        }
    }
}
