<?php

namespace App\Http\Livewire;

use App\Models\Animation;
use App\Models\Resident;
use App\Models\User;
use Mediconesystems\LivewireDatatables\BooleanColumn;
use Mediconesystems\LivewireDatatables\Column;
use Mediconesystems\LivewireDatatables\DateColumn;
use Mediconesystems\LivewireDatatables\NumberColumn;
use Mediconesystems\LivewireDatatables\Http\Livewire\LivewireDatatable;


class ResidentUsers extends LivewireDatatable
{
    public $model = User::class;
    public $residentId/*, $animationUsers*/;
    public $residenceId/*, $animationUsers*/;

    public function mount($model = null, $include = [], $exclude = [], $hide = [], $dates = [], $times = [], $searchable = [], $sort = null, $hideHeader = null, $hidePagination = null, $perPage = null, $exportable = false, $hideable = false, $beforeTableSlot = false, $afterTableSlot = false, $params = [])
    {
        // get residentId and residenceId from params
        $this->residentId = $params;
        $this->resident = Resident::query()->where('id', '=', (int)$this->residentId)->first();
        
//        $this->animationUsers = Animation::find($this->residentId)->users;
        parent::mount($model, $include, $exclude, $hide, $dates, $times, $searchable, $sort, $hideHeader, $hidePagination, $perPage, $exportable, $hideable, $beforeTableSlot, $afterTableSlot, $params);
    }

    public function builder()
    {
        return User::query()->where('id', '!=', (int)$this->resident->id_residence);
    }

    public function columns()
    {
        return [
            NumberColumn::name('id'),
            Column::name('name')->searchable(),
            Column::name('language')->filterable(['fr', 'en']),
            BooleanColumn::name('active')->filterable(),
            Column::name('subscription')->filterable(['basic', 'premium', 'gold']),
            DateColumn::name('created_at'),  
            Column::callback(['id'], function ($id) {
                return view('livewire/resident-users-actions', ['residentId' => $id]);
            })->label('Actions'), 
        ];
    }

    public function addResidentToResidence($id)
    {
        Resident::query()->where('id', '=', (int)$this->residentId)->update(['id_residence' => $id]);
        // redirect to /residents
        return redirect()->route('residents');
    }
}
