<?php

namespace App\Http\Livewire;

use App\Models\Animation;
use App\Models\User;
use Mediconesystems\LivewireDatatables\BooleanColumn;
use Mediconesystems\LivewireDatatables\Column;
use Mediconesystems\LivewireDatatables\DateColumn;
use Mediconesystems\LivewireDatatables\NumberColumn;
use Mediconesystems\LivewireDatatables\Http\Livewire\LivewireDatatable;
use Mediconesystems\LivewireDatatables\TimeColumn;

class UserAnimations extends LivewireDatatable
{
    public $model = Animation::class;
    public $userId/*, $userAnimations*/;

    public function mount($model = null, $include = [], $exclude = [], $hide = [], $dates = [], $times = [], $searchable = [], $sort = null, $hideHeader = null, $hidePagination = null, $perPage = null, $exportable = false, $hideable = false, $beforeTableSlot = false, $afterTableSlot = false, $params = [])
    {
        $this->userId = $this->params;
//        $this->userAnimations = User::find($this->userId)->animations;
        parent::mount($model, $include, $exclude, $hide, $dates, $times, $searchable, $sort, $hideHeader, $hidePagination, $perPage, $exportable, $hideable, $beforeTableSlot, $afterTableSlot, $params);
    }

    public function builder()
    {
        return Animation::query()->leftJoin('animation_user', function ($join) {
            $join->on('animation_user.animation_id', 'animations.id')->where('animation_user.user_id', '=', (int)$this->userId);
        });
    }

    public function columns()
    {
        return [
            NumberColumn::name('id'),
            Column::name('name')->searchable(),
            Column::name('showman')->searchable(),
            Column::name('type')->filterable(['quizz', 'culture', 'news']),
            DateColumn::name('date')->filterable(),
            TimeColumn::name('date as time')->label('time'),
            BooleanColumn::name('animation_user.id')->label('linked')->filterable(),
//            BooleanColumn::raw("( SELECT 1 FROM animation_user WHERE animation_user.animation_id = animations.id AND animation_user.user_id = {$this->userId} ) AS linked")->label('linked')->filterable(),
            /*BooleanColumn::name('users.name')
                ->filterable()
                ->label('linked'),*/
            /*BooleanColumn::scope('hasUser', 'linked')
                ->filterable(null, 'filterHasUser'),
            Column::callback(['id'], function($id) {
                return $this->userAnimations->contains($id) ? "Yes" : "No";
            })->label('linked')->filterable(),*/
            Column::callback(['id', 'animation_user.id'], function ($id, $linked) {
                return view('livewire/user-animations-actions', ['id' => $id, 'linked' => $linked, 'userId' => $this->userId]);
            })->label('Actions'),
        ];
    }

    public function addAnimation($id)
    {
        User::find($this->userId)->animations()->attach($id);
    }

    public function deleteAnimation($id)
    {
        User::find($this->userId)->animations()->detach($id);
    }
}
