<?php

namespace App\Http\Livewire;

use App\Models\User;
use Carbon\Carbon;
use Illuminate\Support\Facades\Hash;
use Livewire\Component;

class UserEdit extends Component
{
    public $userId = null;
    public $password = '';
    public User $user;
    public $saveMethod = 'store';

    protected $rules = [
        'user.name' => 'required|string|unique:users,name',
        'user.language' => 'required|string|in:fr,en',
        'user.subscription' => 'required|string|in:basic,premium,gold',
        'user.external_id' => 'required|string',
        'user.phone' => 'string',
        'user.postal_code' => 'string',
        'user.started_at' => 'date',
        'user.email' => 'required|email',
        'password' => 'string',
        'user.active' => 'required|boolean',
    ];

    public function mount() {
        if($this->userId) {
            $user = User::where('id', $this->userId)->firstOrFail();
            $this->user = $user;
            $this->saveMethod = 'update';
        } else {
            $this->user = new User();
        }
    }

    public function render()
    {
        return view('livewire.user-form');
    }

    public function updated($propertyName)
    {
        $this->validateOnly($propertyName);
    }

    public function store()
    {
        $this->validate();
        $this->validate(['password' => 'required', 'user.email' => 'unique:users,email']);

        $this->user->password = Hash::make($this->password);
        $this->user->password_plain = $this->password;
        $this->user->email_verified_at = now();

        if($this->user->save()) {
            $this->user->assignRole('user');
            session()->flash('message', 'User Created Successfully.');
            return redirect()->route('users.edit', [$this->user->id]);
        } else {
            session()->flash('error-message', 'An unknown error occured.');
        }

    }

    public function update()
    {
        $this->validate();
        $this->validate(['user.email' => 'unique:users,email,' . $this->userId]);

        if($this->password) {
            $this->user->password = Hash::make($this->password);
            $this->user->password_plain = $this->password;
        }

        if($this->user->save()) {
            $this->password = "";
            session()->flash('message', 'User Updated Successfully.');
        } else {
            session()->flash('error-message', 'An unknown error occured.');
        }
    }
}
