<?php

namespace App\Models;

use Carbon\Carbon;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Laravel\Sanctum\HasApiTokens;
use Spatie\Permission\Traits\HasRoles;



class User extends Authenticatable
{
    use HasFactory, Notifiable, hasRoles, HasApiTokens;

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'name',
        'language',
        'email',
        'email_verified_at',
        'active',
        'password',
        'password_plain',
        'subscription',
        'external_id',
        'phone',
        'postal_code',
        'started_at',
    ];

    /**
     * The attributes that should be hidden for arrays.
     *
     * @var array
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];

    /**
     * The attributes that should be cast to native types.
     *
     * @var array
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
        'started_at' => 'datetime',
        'active' => 'boolean',
    ];

    public static function boot()
    {
        parent::boot();

        static::deleting(function($model) {
            $model->animations()->detach();
        });
    }

    public function getStartedAtAttribute($value)
    {
        return Carbon::parse($value)->format('Y-m-d\TH:i');
    }

    public function residences()
    {
        return $this->hasMany(Resident::class,"id_residence")->get();
    }

    public function animations()
    {
        return $this->belongsToMany(Animation::class)->withPivot('activated');
    }

    public function activeAnimations()
    {
        return $this->animations()->where('date', '>=', Carbon::now()->subHours(2));
    }

    public function nextAnimationsSameDay()
    {
        $first = $this->activeAnimations()->orderBy('date')->first();
        return $first ?
            $this->activeAnimations()->where('date', 'like', Carbon::parse($first->date)->format("Y-m-d") . "%")->orderBy('date')->get() :
            [];
    }
}
